@@ -122,8 +122,7 @@ def require_login(fn: F) -> F:
     @click.pass_context
     @wraps(fn)
     def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
-        config = Config.instance()
-        if "org" not in config:
+        if not Config.is_logged_in():
             raise CliError("Please run `sym login` first")
         return context.invoke(fn, *args, **kwargs)
 
