@@ -34,18 +34,26 @@ def xdg_config_home() -> Path:
 
 
 def sym_config_file(file_name: str) -> Path:
-    sym_config_home = xdg_config_home() / "sym"
-    return sym_config_home / file_name
+    return xdg_config_home() / "sym" / file_name
 
 
 class SymConfigFile:
-    def __init__(self, *, file_name: str, **dependencies):
+    def __init__(self, *, file_name: str, uid_scope: bool = True, **dependencies):
         path = Path()
+
         if dependencies:
             key = json.dumps(dependencies, sort_keys=True).encode("utf-8")
             md5 = hashlib.md5(key).hexdigest()
             path = path / md5
-        self.path = sym_config_file(path / file_name)
+
+        path = path / file_name
+
+        if uid_scope:
+            path = Path("uid") / str(os.getuid()) / path
+        else:
+            path = Path("default") / path
+
+        self.path = sym_config_file(path)
 
         self.read_lock = read_lock(self.path)
         self.write_lock = create_lock(self.path)
@@ -130,7 +138,7 @@ class Config(MutableMapping[ConfigKey, Any]):
     config: Final[ConfigSchema]
 
     def __init__(self) -> None:
-        self.file = SymConfigFile(file_name="config.yml")
+        self.file = SymConfigFile(file_name="config.yml", uid_scope=False)
         with self.file as f:
             self.__load(f)
 
@@ -189,6 +197,10 @@ class Config(MutableMapping[ConfigKey, Any]):
     def get_default(cls, key) -> Optional[str]:
         return cls.instance().get(f"default_{key}")
 
+    @classmethod
+    def is_logged_in(cls):
+        return "email" in cls.instance()
+
     @classmethod
     def get_org(cls) -> str:
         return cls.instance()["org"]
