@@ -1,23 +1,17 @@
-from contextlib import contextmanager
+from contextlib import ExitStack, contextmanager
 from os import environ
-from typing import Callable, Generator, Optional, Union
-
+from typing import Iterator, Mapping, Optional
 
 EnvValue = Optional[str]
 
 
-def _set_env(
-    key: str, value: Union[EnvValue, Callable[[EnvValue], EnvValue]]
-) -> EnvValue:
+def _set_env(key: str, value: EnvValue) -> EnvValue:
     last: EnvValue
     try:
         last = environ[key]
     except KeyError:
         last = None
 
-    if callable(value):
-        value = value(last)
-
     if value is not None:
         environ[key] = value
     elif last is not None:
@@ -26,12 +20,18 @@ def _set_env(
 
 
 @contextmanager
-def push_env(
-    key: str, value: Union[EnvValue, Callable[[EnvValue], EnvValue]]
-) -> Generator[EnvValue, None, None]:
+def push_env(key: str, value: EnvValue) -> Iterator[EnvValue]:
     saved = _set_env(key, value)
 
     try:
         yield saved
     finally:
         _set_env(key, saved)
+
+
+@contextmanager
+def push_envs(envs: Mapping[str, EnvValue]) -> Iterator[EnvValue]:
+    with ExitStack() as stack:
+        for k, v in envs.items():
+            stack.enter_context(push_env(k, v))
+        yield
