@@ -19,11 +19,11 @@ def keywords_to_options(args: Sequence[Argument]) -> List[str]:
             result.append(arg)
             continue
         for (key, value) in arg.items():
-            if value is False:
+            if value in (False, None):
                 continue
             prefix = "-" if len(key) == 1 else "--"
             option = prefix + key.replace("_", "-")
-            if not isinstance(value, list):
+            if not isinstance(value, (tuple, list)):
                 value = [value]
             for val in value:
                 result.append(option)
