@@ -28,6 +28,8 @@ def config_option(
 def _resource_callback(ctx, resource: str, saml_client_name: str):
     if resource is None:
         return None
+    if not Config.is_logged_in():
+        return resource
     saml_client = choose_saml_client(saml_client_name)
     if not saml_client.validate_resource(resource):
         raise click.BadParameter(f"Invalid resource: {resource}")
