@@ -60,8 +60,13 @@ class SymGroup(Group):
         super().__init__(*args, **attrs)
 
     def __del__(self):
-        for tee in self.__class__.tees:
+        self.__class__.reset_tees()
+
+    @classmethod
+    def reset_tees(cls):
+        for tee in cls.tees:
             tee.close()
+        cls.tees = []
 
     def invoke(self, ctx: Context) -> Any:
         if (log_dir := ctx.params.get("log_dir")) :
