@@ -40,6 +40,7 @@ class AwsProfile(SAMLClient):
     def get_creds(self):
         creds = {k.upper(): v for k, v in self._section.items() if k.startswith("aws")}
         creds["AWS_REGION"] = self._section.get("REGION")
+        creds["AWS_CREDENTIAL_EXPIRATION"] = self._section.get("x_security_token_expires")
         return creds
 
     @intercept_errors()
@@ -56,9 +57,7 @@ class AwsProfile(SAMLClient):
     def _ensure_config(self, profile: Profile) -> ConfigParser:
         return ConfigParser()
 
-    def _ensure_session(self):
-        if (expires := self._section.get("x_security_token_expires")) :
-            parsed = datetime.fromisoformat(expires)
-            if parsed > datetime.now(parsed.tzinfo):
-                return
+    def _ensure_session(self, *, force: bool):
+        if not force and not self._creds_expiring():
+            return
         get_identity(self)
