@@ -72,7 +72,7 @@ class Saml2Aws(SAMLClient):
     @intercept_errors(ErrorPatterns, suppress=True)
     @run_subprocess
     @require_bins(binary)
-    def _login(self, show_prompt=False):
+    def _login(self, show_prompt=False, force=False):
         if show_prompt:
             options = {**self._s2a_options, "skip_prompt": False}
             args = {"username": Config.get_email()}
@@ -80,13 +80,14 @@ class Saml2Aws(SAMLClient):
             options = self._s2a_options
             args = {}
         with push_env("AWS_REGION", self.ensure_config()["sym"]["region"]):
-            yield "saml2aws", options, "login", args  # no-op if session active
+            # no-op if session active when force=False
+            yield "saml2aws", options, "login", args, {"force": force}
 
-    def _ensure_session(self):
+    def _ensure_session(self, *, force: bool):
         try:
-            self._login(silence_stderr_=not self.debug)
+            self._login(silence_stderr_=not self.debug, force=force)
         except FailedSubprocessError:
-            self._login(silence_stderr_=not self.debug, show_prompt=True)
+            self._login(silence_stderr_=not self.debug, force=force, show_prompt=True)
 
     def _ensure_config(self, profile: Profile) -> ConfigParser:
         saml2aws_params = get_saml2aws_params()
