@@ -3,6 +3,7 @@ import shlex
 import sys
 from abc import ABC, abstractmethod
 from configparser import ConfigParser
+from datetime import datetime, timedelta
 from operator import attrgetter
 from pathlib import Path
 from typing import ClassVar, Final, Optional, Type
@@ -100,12 +101,12 @@ class SAMLClient(ABC):
         self.dprint(f"client: {self.cli_options}")
         return self._exec(*args, **kwargs)
 
-    def _ensure_session(self):
+    def _ensure_session(self, *, force: bool):
         self._exec("true", silence_stderr_=False, suppress_=True)
 
-    def ensure_session(self):
+    def ensure_session(self, force=False):
         if not self._session_exists:
-            self._ensure_session()
+            self._ensure_session(force=force)
             self._session_exists = True
 
     def ensure_config(self) -> ConfigParser:
@@ -165,7 +166,16 @@ class SAMLClient(ABC):
             )
         }
 
+    def _creds_expiring(self, buffer=timedelta(minutes=15)):
+        if (expires := self.get_creds().get("AWS_CREDENTIAL_EXPIRATION")) :
+            parsed = datetime.fromisoformat(expires)
+            return datetime.now(parsed.tzinfo) + buffer < parsed
+        return False
+
     def write_creds(self, *, path: Path, profile: str):
+        if self._creds_expiring():
+            self._ensure_session(force=True)
+
         creds = self.get_creds()
         creds["region"] = creds.pop("AWS_REGION", None)
         creds["x_security_token_expires"] = creds.pop("AWS_CREDENTIAL_EXPIRATION", None)
