@@ -19,7 +19,7 @@ class CaptureCommand:
     # `args` has a much more constrained type than subprocess.run normally allows.
     def _run_stub(self, args: Sequence[str], **_kwargs: Any) -> None:
         self.commands.append(list(args))
-        output = self.outputs.pop() if self.outputs else None
+        output = self.outputs.pop(0) if self.outputs else None
         return subprocess.CompletedProcess(args=args, returncode=0, stdout=output)
 
     @contextmanager
@@ -28,8 +28,8 @@ class CaptureCommand:
             mp.setattr(subprocess, "run", self._run_stub)
             yield
 
-    def enqueue_output(self, output: str) -> None:
-        self.outputs.append(output)
+    def enqueue_outputs(self, *outputs: Sequence[str]) -> None:
+        self.outputs.extend(outputs)
 
     def assert_command(self, *commands: str) -> None:
         assert len(self.commands) == len(commands)
