@@ -11,8 +11,12 @@ class Sandbox:
     def __init__(self, path: Path) -> None:
         self.path = path
 
-    def create_binary(self, name):
-        self.create_file(name, mode=0o755, contents="#!/bin/bash\n")
+    def create_binary(self, name, exist_ok=True):
+        try:
+            self.create_file(name, mode=0o755, contents="#!/bin/bash\n")
+        except FileExistsError:
+            if not exist_ok:
+                raise
 
     def create_file(
         self, name: str, mode: int = 0o644, contents: Optional[str] = None
