@@ -18,6 +18,13 @@ def test_login(click_setup):
         assert result.output == "Sym successfully initalized!\n"
 
 
+def test_ssh_no_login(click_setup):
+    with click_setup(set_org=False) as runner:
+        result = runner.invoke(click_command, ["ssh", "test", "127.0.0.1"])
+        assert result.exit_code > 0
+        assert result.output == "Error: Please run `sym login` first\n"
+
+
 def test_resources(click_setup):
     with click_setup() as runner:
         result = runner.invoke(click_command, ["resources"])
